// DEBUG CONSOLE EXAMPLE v1.1
// Code by Kvin Drapel - 2002
// http://www.calodox.org
//
// Thanks to Richard D for the TraceListener idea
//
// Do what you want with this source.
//

#define TRACE

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.IO;
using System.Text;
using System.Diagnostics;



namespace System.Diagnostics
{

	// DebugConsole Singleton
	sealed class DebugConsole : TraceListener
	{
		public static readonly DebugConsole Instance = 
			new DebugConsole();

		private DebugConsoleWrapper DebugForm = new DebugConsoleWrapper();
		
		// if this parameter is set to true, a call to WriteLine will always create a new row
		// (if false, it may be appended to the current buffer created with some Write calls)
		private bool UseCrWl = true;

		private DebugConsole() 
		{
			DebugForm.Show();
		}

		public void Init(bool UseDebugOutput, bool UseCrForWriteLine)
		{
			if (UseDebugOutput==true)
				Debug.Listeners.Add(this);
			else
				Trace.Listeners.Add(this);

			this.UseCrWl = UseCrForWriteLine;
		}

		override public void Write(string message) 
		{   
			DebugForm.Buffer.Append(message);
			DebugForm.UpdateCurrentRow(false);
		}

		override public void WriteLine(string message) 
		{     

			if (this.UseCrWl==true) 
			{
				DebugForm.CreateEventRow();
				DebugForm.Buffer=new StringBuilder();
			}

			DebugForm.Buffer.Append(message); 
			DebugForm.UpdateCurrentRow(true);
			DebugForm.Buffer = new StringBuilder(); 
		}
	}
}
